@@ -113,11 +113,10 @@ def alignmentEnd(s: str, startOffset: int, length: int) -> int:
 
 class Gb2Alignment:
     """
-    Methods for working with a SARS-CoV-2 genome aligned to a reference.
+    Methods for working with a genome aligned to a GenBank reference.
 
     @param genome: A C{dark.reads.Read} instance.
-    @param features: An C{Features} instance. If not given, the features from
-        the Wuhan reference (NC_045512.2) are used.
+    @param features: An C{Features} instance.
     @param referenceAligned: A C{dark.reads.Read} instance with an aligned
         reference sequence, or C{None} if the alignment should be done here.
         If not C{None} then C{genomeAligned} must also be given.
@@ -143,7 +142,7 @@ class Gb2Alignment:
     def __init__(
         self,
         genome: DNARead,
-        features: Optional[Features] = None,
+        features: Features,
         referenceAligned: Optional[DNARead] = None,
         genomeAligned: Optional[DNARead] = None,
         aligner: str = DEFAULT_ALIGNER,
