@@ -58,7 +58,7 @@ class Features(UserDict):
         gap in its nucleotide sequence.
     """
 
-    REF_GB = DATA_DIR / "NC_045512.2.gb"
+    WUHAN_REF = DATA_DIR / "NC_045512.2.gb"
 
     def __init__(
         self,
@@ -74,7 +74,7 @@ class Features(UserDict):
         self.translatedNames: Optional[Set[str]] = None
 
         if sars2:
-            spec = self.REF_GB if spec is None else spec
+            spec = self.WUHAN_REF if spec is None else spec
         else:
             if spec is None:
                 raise ValueError(
